#
# spec file for package python-raven
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-raven
Version:        6.10.0
Release:        lp152.2.1
Summary:        A client for Sentry
License:        BSD-3-Clause
URL:            https://github.com/getsentry/raven-python
Source:         https://files.pythonhosted.org/packages/source/r/raven/raven-%{version}.tar.gz
# https://github.com/getsentry/raven-python/issues/1284
Patch0:         remove-unittest2.patch
Patch1:         pytest4.patch
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module Flask >= 0.8}
BuildRequires:  %{python_module Flask-Login >= 0.2.0}
BuildRequires:  %{python_module Logbook}
BuildRequires:  %{python_module Paste}
BuildRequires:  %{python_module WebOb}
BuildRequires:  %{python_module WebTest}
BuildRequires:  %{python_module ZConfig}
BuildRequires:  %{python_module anyjson}
BuildRequires:  %{python_module blinker >= 1.1}
BuildRequires:  %{python_module bottle}
BuildRequires:  %{python_module celery >= 2.5}
BuildRequires:  %{python_module exam >= 0.5.2}
BuildRequires:  %{python_module kombu}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest-pythonpath}
BuildRequires:  %{python_module pytest-timeout >= 0.4}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tornado >= 4.1}
BuildRequires:  %{python_module vine}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-Flask >= 0.8
Recommends:     python-blinker >= 1.1
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python-web.py
%endif
%python_subpackages

%description
Raven is a Python client for Sentry. It supports many frameworks,
including Django, Flask, and Pylons. Raven also includes drop-in
support for any WSGI-compatible web application.

%prep
%setup -q -n raven-%{version}
%autopatch -p1

rm -f setup.cfg tox.ini pytest.ini

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand rm -rf %{buildroot}/%{$python_sitelib}/raven/data/cacert.pem

%check
export DJANGO_SETTINGS_MODULE=tests.contrib.django.settings
%pytest -k 'not (TornadoAsyncClientTestCase or TornadoTransportTests)'

%files %{python_files}
%license LICENSE
%doc README.rst
%python3_only %{_bindir}/raven
%{python_sitelib}/*

%changelog
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Nov  4 2019 Matej Cepl <mcepl@suse.com>
- Add pytest4.patch allowing the test suite to pass with pytest 4
* Mon Sep 23 2019 John Vandenberg <jayvdb@gmail.com>
- Undo tornado version change causing package to break
- Re-enable test suite
- Remove unnecessary build dependencies on dev tools
* Mon Aug 26 2019 Todd R <toddrme2178@gmail.com>
- Use better way to handle tornado version compatibility.
* Fri Jul 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not depend on pytest-sugar, it is just pretty-formatter
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary.
- Ensure neutrality of descriptions.
* Tue May 14 2019 John Jolly <jjolly@suse.com>
- Update to 6.10.0:
  + [Core] Fixed stackframes in some situations being in inverse order.
  + [Flask] Fix wrong exception handling logic (accidentally relied on Flask internals).
  + [Core] No longer send NaN local vars as non-standard JSON.
- Refresh patch remove-unittest2.patch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Aug 10 2018 mcepl@suse.com
- Remove unnecessary dependency on unittest2 and contextlib2 modules.
  Add remove-unittest2.patch fixing the code.
* Thu Jul 19 2018 mcepl@suse.com
- Upgrade to 6.9.0:
    too many changes to enlist here, complete list is at
    https://github.com/getsentry/raven-python/blob/master/CHANGELOG.md
- Remove component.xml and kill_bad_test.patch (unnecessary for the
  current version)
* Thu Jan 11 2018 mimi.vx@gmail.com
- update to 6.4.0
- added kill_bad_test.patch
- dropped zconfig_tests.patch
  * [Core] Support for defining sanitized_keys on the client
  * [Django] Support for Django 2.0 Urlresolver
  * [Docs] Several fixes and improvements
* Wed Nov 15 2017 mimi.vx@gmail.com
- update to 6.3.0
- add zconfig_tests.patch and component.xml fixing zconfig support
  * [Core] Changed default timeout on http calls to 5 seconds
  * [Core] Fixed relative paths for traces generated on Windows
  * [Django] Fixed import issues for Django projects < 1.7
  * [Django] Fixed django management command data option
  * [Django/DRF] Added application/octet-stream to non-cacheable types in middleware
  * [Django] Added parsing X-Forwarded-For for user.ip_address
  * [Flask] Added request.remote_addr as fallback for ip addresses
  * [Lambda] Added initial AWS Lambda support with contrib.awslambda.LambdaClient
  * [Core] get_frame_locals properly using max_var_size
  * [Core] Fixed raven initialization when logging._srcfile is None
  * [Core] Fixed import locking to avoid recursion
  * [Django] Fixed several issues for Django 1.11 and Django 2.0
  * [Django/DRF] Fixed issue with unavailable request data
  * [Flask] Added app.logger instrumentation
  * [Flask] Added signal on setup_logging
  * [ZConfig] Added standalone ZConfig support
  * [Celery] Fixed several issues related to Celery*
* Thu Sep  7 2017 toddrme2178@gmail.com
- initial version
